@@ -23,7 +23,7 @@ module Gitlab
         return hash if cookie.to_s.empty?
         return hash.merge(key => cookie) if hash[key].nil?
 
-        add_migration(key => cookie)
+        add_unmerged_migration(key => cookie)
         cookie_jar.delete(cookie_name, domain: domain)
 
         hash
